Class: Google::Apis::AppengineV1beta::ContainerInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Docker image that is used to create a container and start a VM instance for the version that you deploy. Only applicable for instances running in the App Engine flexible environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContainerInfo

Returns a new instance of ContainerInfo.



610
611
612
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#imageString

URI to the hosted container image in Google Container Registry. The URI must be fully qualified and include a tag or digest. Examples: "gcr.io/my-project/ image:tag" or "gcr.io/my-project/image@digest" Corresponds to the JSON property image

Returns:

  • (String)


608
609
610
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 608

def image
  @image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



615
616
617
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 615

def update!(**args)
  @image = args[:image] if args.key?(:image)
end