Class: Google::Apis::AppengineV1beta::ContainerState
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::ContainerState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH. This data is not persisted by CCFE, but is instead derived from CCFE's internal representation of the container state.
Instance Attribute Summary collapse
-
#current_reasons ⇒ Google::Apis::AppengineV1beta::Reasons
Containers transition between and within states based on reasons sent from various systems.
-
#previous_reasons ⇒ Google::Apis::AppengineV1beta::Reasons
Containers transition between and within states based on reasons sent from various systems.
-
#state ⇒ String
The current state of the container.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContainerState
constructor
A new instance of ContainerState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContainerState
Returns a new instance of ContainerState.
651 652 653 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_reasons ⇒ Google::Apis::AppengineV1beta::Reasons
Containers transition between and within states based on reasons sent from
various systems. CCFE will provide the CLH with reasons for the current state
per system.The current systems that CCFE supports are: Service Management (
Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud
Billing API) Service Activation (Service Controller)
Corresponds to the JSON property currentReasons
634 635 636 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 634 def current_reasons @current_reasons end |
#previous_reasons ⇒ Google::Apis::AppengineV1beta::Reasons
Containers transition between and within states based on reasons sent from
various systems. CCFE will provide the CLH with reasons for the current state
per system.The current systems that CCFE supports are: Service Management (
Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud
Billing API) Service Activation (Service Controller)
Corresponds to the JSON property previousReasons
643 644 645 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 643 def previous_reasons @previous_reasons end |
#state ⇒ String
The current state of the container. This state is the culmination of all of
the opinions from external systems that CCFE knows about of the container.
Corresponds to the JSON property state
649 650 651 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 649 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
656 657 658 659 660 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 656 def update!(**args) @current_reasons = args[:current_reasons] if args.key?(:current_reasons) @previous_reasons = args[:previous_reasons] if args.key?(:previous_reasons) @state = args[:state] if args.key?(:state) end |