Class: Google::Apis::AppengineV1beta::DomainMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

A domain serving an App Engine application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DomainMapping

Returns a new instance of DomainMapping.



976
977
978
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Relative name of the domain serving the application. Example: example.com. Corresponds to the JSON property id

Returns:

  • (String)


956
957
958
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 956

def id
  @id
end

#nameString

Output only. Full path to the DomainMapping resource in the API. Example: apps/ myapp/domainMapping/example.com.@OutputOnly Corresponds to the JSON property name

Returns:

  • (String)


962
963
964
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 962

def name
  @name
end

#resource_recordsArray<Google::Apis::AppengineV1beta::ResourceRecord>

Output only. The resource records required to configure this domain mapping. These records must be added to the domain's DNS configuration in order to serve the application via this domain mapping.@OutputOnly Corresponds to the JSON property resourceRecords



969
970
971
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 969

def resource_records
  @resource_records
end

#ssl_settingsGoogle::Apis::AppengineV1beta::SslSettings

SSL configuration for a DomainMapping resource. Corresponds to the JSON property sslSettings



974
975
976
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 974

def ssl_settings
  @ssl_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



981
982
983
984
985
986
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 981

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_records = args[:resource_records] if args.key?(:resource_records)
  @ssl_settings = args[:ssl_settings] if args.key?(:ssl_settings)
end