Class: Google::Apis::AppengineV1beta::EndpointsApiService

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Google Cloud Endpoints (https://cloud.google.com/endpoints) configuration. The Endpoints API Service provides tooling for serving Open API and gRPC endpoints via an NGINX proxy. Only valid for App Engine Flexible environment deployments. The fields here refer to the name and configuration ID of a "service" resource in the Service Management API (https://cloud.google.com/service-management/ overview).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndpointsApiService

Returns a new instance of EndpointsApiService.



1045
1046
1047
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_idString

Endpoints service configuration ID as specified by the Service Management API. For example "2016-09-19r1".By default, the rollout strategy for Endpoints is RolloutStrategy.FIXED. This means that Endpoints starts up with a particular configuration ID. When a new configuration is rolled out, Endpoints must be given the new configuration ID. The config_id field is used to give the configuration ID and is required in this case.Endpoints also has a rollout strategy called RolloutStrategy.MANAGED. When using this, Endpoints fetches the latest configuration and does not need the configuration ID. In this case, config_id must be omitted. Corresponds to the JSON property configId

Returns:

  • (String)


1025
1026
1027
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1025

def config_id
  @config_id
end

#disable_trace_samplingBoolean Also known as: disable_trace_sampling?

Enable or disable trace sampling. By default, this is set to false for enabled. Corresponds to the JSON property disableTraceSampling

Returns:

  • (Boolean)


1030
1031
1032
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1030

def disable_trace_sampling
  @disable_trace_sampling
end

#nameString

Endpoints service name which is the name of the "service" resource in the Service Management API. For example "myapi.endpoints.myproject.cloud.goog" Corresponds to the JSON property name

Returns:

  • (String)


1037
1038
1039
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1037

def name
  @name
end

#rollout_strategyString

Endpoints rollout strategy. If FIXED, config_id must be specified. If MANAGED, config_id must be omitted. Corresponds to the JSON property rolloutStrategy

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1043

def rollout_strategy
  @rollout_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1050
1051
1052
1053
1054
1055
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1050

def update!(**args)
  @config_id = args[:config_id] if args.key?(:config_id)
  @disable_trace_sampling = args[:disable_trace_sampling] if args.key?(:disable_trace_sampling)
  @name = args[:name] if args.key?(:name)
  @rollout_strategy = args[:rollout_strategy] if args.key?(:rollout_strategy)
end