Class: Google::Apis::AppengineV1beta::ErrorHandler

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Custom static error page to be served when an error occurs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ErrorHandler

Returns a new instance of ErrorHandler.



1096
1097
1098
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeString

Error condition this handler applies to. Corresponds to the JSON property errorCode

Returns:

  • (String)


1084
1085
1086
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1084

def error_code
  @error_code
end

#mime_typeString

MIME type of file. Defaults to text/html. Corresponds to the JSON property mimeType

Returns:

  • (String)


1089
1090
1091
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1089

def mime_type
  @mime_type
end

#static_fileString

Static file content to be served for this error. Corresponds to the JSON property staticFile

Returns:

  • (String)


1094
1095
1096
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1094

def static_file
  @static_file
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1101
1102
1103
1104
1105
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1101

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @static_file = args[:static_file] if args.key?(:static_file)
end