Class: Google::Apis::AppengineV1beta::FirewallRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

A single firewall rule that is evaluated against incoming traffic and provides an action to take on matched requests. A positive integer between 1, Int32. MaxValue-1 that defines the order of rule evaluation. Rules with the lowest priority are evaluated first.A default rule at priority Int32.MaxValue matches all IPv4 and IPv6 traffic when no previous rule matches. Only the action of this rule can be modified by the user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallRule

Returns a new instance of FirewallRule.



1233
1234
1235
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The action to take on matched requests. Corresponds to the JSON property action

Returns:

  • (String)


1209
1210
1211
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1209

def action
  @action
end

#descriptionString

An optional string description of this rule. This field has a maximum length of 400 characters. Corresponds to the JSON property description

Returns:

  • (String)


1215
1216
1217
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1215

def description
  @description
end

#priorityFixnum

Corresponds to the JSON property priority

Returns:

  • (Fixnum)


1220
1221
1222
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1220

def priority
  @priority
end

#source_rangeString

IP address or range, defined using CIDR notation, of requests that this rule applies to. You can use the wildcard character "*" to match all IPs equivalent to "0/0" and "::/0" together. Examples: 192.168.1.1 or 192.168.0.0/16 or 2001: db8::/32 or 2001:0db8:0000:0042:0000:8a2e:0370:7334. Truncation will be silently performed on addresses which are not properly truncated. For example, 1.2.3.4/24 is accepted as the same address as 1.2.3.0/24. Similarly, for IPv6, 2001:db8::1/32 is accepted as the same address as 2001:db8::/32. Corresponds to the JSON property sourceRange

Returns:

  • (String)


1231
1232
1233
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1231

def source_range
  @source_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1238
1239
1240
1241
1242
1243
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1238

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @description = args[:description] if args.key?(:description)
  @priority = args[:priority] if args.key?(:priority)
  @source_range = args[:source_range] if args.key?(:source_range)
end