Class: Google::Apis::AppengineV1beta::FlexibleRuntimeSettings
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::FlexibleRuntimeSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Runtime settings for the App Engine flexible environment.
Instance Attribute Summary collapse
-
#operating_system ⇒ String
The operating system of the application runtime.
-
#runtime_version ⇒ String
The runtime version of an App Engine flexible application.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleRuntimeSettings
constructor
A new instance of FlexibleRuntimeSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleRuntimeSettings
Returns a new instance of FlexibleRuntimeSettings.
1237 1238 1239 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operating_system ⇒ String
The operating system of the application runtime.
Corresponds to the JSON property operatingSystem
1230 1231 1232 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1230 def @operating_system end |
#runtime_version ⇒ String
The runtime version of an App Engine flexible application.
Corresponds to the JSON property runtimeVersion
1235 1236 1237 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1235 def runtime_version @runtime_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1242 1243 1244 1245 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1242 def update!(**args) @operating_system = args[:operating_system] if args.key?(:operating_system) @runtime_version = args[:runtime_version] if args.key?(:runtime_version) end |