Class: Google::Apis::AppengineV1beta::GoogleAppengineV1betaLocationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Metadata for the given google.cloud.location.Location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleAppengineV1betaLocationMetadata

Returns a new instance of GoogleAppengineV1betaLocationMetadata.



1322
1323
1324
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#flexible_environment_availableBoolean Also known as: flexible_environment_available?

App Engine flexible environment is available in the given location.@OutputOnly Corresponds to the JSON property flexibleEnvironmentAvailable

Returns:

  • (Boolean)


1306
1307
1308
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1306

def flexible_environment_available
  @flexible_environment_available
end

#search_api_availableBoolean Also known as: search_api_available?

Output only. Search API (https://cloud.google.com/appengine/docs/standard/ python/search) is available in the given location. Corresponds to the JSON property searchApiAvailable

Returns:

  • (Boolean)


1313
1314
1315
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1313

def search_api_available
  @search_api_available
end

#standard_environment_availableBoolean Also known as: standard_environment_available?

App Engine standard environment is available in the given location.@OutputOnly Corresponds to the JSON property standardEnvironmentAvailable

Returns:

  • (Boolean)


1319
1320
1321
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1319

def standard_environment_available
  @standard_environment_available
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1327
1328
1329
1330
1331
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1327

def update!(**args)
  @flexible_environment_available = args[:flexible_environment_available] if args.key?(:flexible_environment_available)
  @search_api_available = args[:search_api_available] if args.key?(:search_api_available)
  @standard_environment_available = args[:standard_environment_available] if args.key?(:standard_environment_available)
end