Class: Google::Apis::AppengineV1beta::HealthCheck

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances. Only applicable for instances in App Engine flexible environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheck

Returns a new instance of HealthCheck.



1379
1380
1381
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_intervalString

Interval between health checks. Corresponds to the JSON property checkInterval

Returns:

  • (String)


1343
1344
1345
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1343

def check_interval
  @check_interval
end

#disable_health_checkBoolean Also known as: disable_health_check?

Whether to explicitly disable health checks for this instance. Corresponds to the JSON property disableHealthCheck

Returns:

  • (Boolean)


1348
1349
1350
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1348

def disable_health_check
  @disable_health_check
end

#healthy_thresholdFixnum

Number of consecutive successful health checks required before receiving traffic. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


1355
1356
1357
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1355

def healthy_threshold
  @healthy_threshold
end

#hostString

Host header to send when performing an HTTP health check. Example: "myapp. appspot.com" Corresponds to the JSON property host

Returns:

  • (String)


1361
1362
1363
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1361

def host
  @host
end

#restart_thresholdFixnum

Number of consecutive failed health checks required before an instance is restarted. Corresponds to the JSON property restartThreshold

Returns:

  • (Fixnum)


1367
1368
1369
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1367

def restart_threshold
  @restart_threshold
end

#timeoutString

Time before the health check is considered failed. Corresponds to the JSON property timeout

Returns:

  • (String)


1372
1373
1374
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1372

def timeout
  @timeout
end

#unhealthy_thresholdFixnum

Number of consecutive failed health checks required before removing traffic. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


1377
1378
1379
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1377

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1384
1385
1386
1387
1388
1389
1390
1391
1392
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1384

def update!(**args)
  @check_interval = args[:check_interval] if args.key?(:check_interval)
  @disable_health_check = args[:disable_health_check] if args.key?(:disable_health_check)
  @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold)
  @host = args[:host] if args.key?(:host)
  @restart_threshold = args[:restart_threshold] if args.key?(:restart_threshold)
  @timeout = args[:timeout] if args.key?(:timeout)
  @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold)
end