Class: Google::Apis::AppengineV1beta::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

An Instance resource is the computing unit that App Engine uses to automatically scale an application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



1514
1515
1516
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_engine_releaseString

Output only. App Engine release this instance is running on. Corresponds to the JSON property appEngineRelease

Returns:

  • (String)


1422
1423
1424
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1422

def app_engine_release
  @app_engine_release
end

#availabilityString

Output only. Availability of the instance. Corresponds to the JSON property availability

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1427

def availability
  @availability
end

#average_latencyFixnum

Output only. Average latency (ms) over the last minute. Corresponds to the JSON property averageLatency

Returns:

  • (Fixnum)


1432
1433
1434
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1432

def average_latency
  @average_latency
end

#errorsFixnum

Output only. Number of errors since this instance was started. Corresponds to the JSON property errors

Returns:

  • (Fixnum)


1437
1438
1439
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1437

def errors
  @errors
end

#idString

Output only. Relative name of the instance within the version. Example: instance-1. Corresponds to the JSON property id

Returns:

  • (String)


1443
1444
1445
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1443

def id
  @id
end

#memory_usageFixnum

Output only. Total memory in use (bytes). Corresponds to the JSON property memoryUsage

Returns:

  • (Fixnum)


1448
1449
1450
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1448

def memory_usage
  @memory_usage
end

#nameString

Output only. Full path to the Instance resource in the API. Example: apps/ myapp/services/default/versions/v1/instances/instance-1. Corresponds to the JSON property name

Returns:

  • (String)


1454
1455
1456
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1454

def name
  @name
end

#qpsFloat

Output only. Average queries per second (QPS) over the last minute. Corresponds to the JSON property qps

Returns:

  • (Float)


1459
1460
1461
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1459

def qps
  @qps
end

#requestsFixnum

Output only. Number of requests since this instance was started. Corresponds to the JSON property requests

Returns:

  • (Fixnum)


1464
1465
1466
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1464

def requests
  @requests
end

#start_timeString

Output only. Time that this instance was started.@OutputOnly Corresponds to the JSON property startTime

Returns:

  • (String)


1469
1470
1471
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1469

def start_time
  @start_time
end

#vm_debug_enabledBoolean Also known as: vm_debug_enabled?

Output only. Whether this instance is in debug mode. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmDebugEnabled

Returns:

  • (Boolean)


1475
1476
1477
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1475

def vm_debug_enabled
  @vm_debug_enabled
end

#vm_idString

Output only. Virtual machine ID of this instance. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmId

Returns:

  • (String)


1482
1483
1484
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1482

def vm_id
  @vm_id
end

#vm_ipString

Output only. The IP address of this instance. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmIp

Returns:

  • (String)


1488
1489
1490
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1488

def vm_ip
  @vm_ip
end

#vm_livenessString

Output only. The liveness health check of this instance. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmLiveness

Returns:

  • (String)


1494
1495
1496
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1494

def vm_liveness
  @vm_liveness
end

#vm_nameString

Output only. Name of the virtual machine where this instance lives. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmName

Returns:

  • (String)


1500
1501
1502
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1500

def vm_name
  @vm_name
end

#vm_statusString

Output only. Status of the virtual machine where this instance lives. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmStatus

Returns:

  • (String)


1506
1507
1508
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1506

def vm_status
  @vm_status
end

#vm_zone_nameString

Output only. Zone where the virtual machine is located. Only applicable for instances in App Engine flexible environment. Corresponds to the JSON property vmZoneName

Returns:

  • (String)


1512
1513
1514
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1512

def vm_zone_name
  @vm_zone_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1519

def update!(**args)
  @app_engine_release = args[:app_engine_release] if args.key?(:app_engine_release)
  @availability = args[:availability] if args.key?(:availability)
  @average_latency = args[:average_latency] if args.key?(:average_latency)
  @errors = args[:errors] if args.key?(:errors)
  @id = args[:id] if args.key?(:id)
  @memory_usage = args[:memory_usage] if args.key?(:memory_usage)
  @name = args[:name] if args.key?(:name)
  @qps = args[:qps] if args.key?(:qps)
  @requests = args[:requests] if args.key?(:requests)
  @start_time = args[:start_time] if args.key?(:start_time)
  @vm_debug_enabled = args[:vm_debug_enabled] if args.key?(:vm_debug_enabled)
  @vm_id = args[:vm_id] if args.key?(:vm_id)
  @vm_ip = args[:vm_ip] if args.key?(:vm_ip)
  @vm_liveness = args[:vm_liveness] if args.key?(:vm_liveness)
  @vm_name = args[:vm_name] if args.key?(:vm_name)
  @vm_status = args[:vm_status] if args.key?(:vm_status)
  @vm_zone_name = args[:vm_zone_name] if args.key?(:vm_zone_name)
end