Class: Google::Apis::AppengineV1beta::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::ListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::AppengineV1beta::Location>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
1727 1728 1729 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1727 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::AppengineV1beta::Location>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
1720 1721 1722 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1720 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1725 1726 1727 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1725 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1732 1733 1734 1735 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1732 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |