Class: Google::Apis::AppengineV1beta::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



1759
1760
1761
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1745
1746
1747
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1745

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::AppengineV1beta::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



1750
1751
1752
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1750

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1757
1758
1759
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1757

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1764
1765
1766
1767
1768
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1764

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end