Class: Google::Apis::AppengineV1beta::ManagedCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

A certificate managed by App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedCertificate

Returns a new instance of ManagedCertificate.



2004
2005
2006
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_renewal_timeString

Time at which the certificate was last renewed. The renewal process is fully managed. Certificate renewal will automatically occur before the certificate expires. Renewal errors can be tracked via ManagementStatus.@OutputOnly Corresponds to the JSON property lastRenewalTime

Returns:

  • (String)


1996
1997
1998
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1996

def last_renewal_time
  @last_renewal_time
end

#statusString

Status of certificate management. Refers to the most recent certificate acquisition or renewal attempt.@OutputOnly Corresponds to the JSON property status

Returns:

  • (String)


2002
2003
2004
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2002

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2009
2010
2011
2012
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2009

def update!(**args)
  @last_renewal_time = args[:last_renewal_time] if args.key?(:last_renewal_time)
  @status = args[:status] if args.key?(:status)
end