Class: Google::Apis::AppengineV1beta::ManualScaling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

A service with manual scaling runs continuously, allowing you to perform complex initialization and rely on the state of its memory over time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManualScaling

Returns a new instance of ManualScaling.



2004
2005
2006
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesFixnum

Number of instances to assign to the service at the start. This number can later be altered by using the Modules API (https://cloud.google.com/appengine/ docs/python/modules/functions) set_num_instances() function. Corresponds to the JSON property instances

Returns:

  • (Fixnum)


2002
2003
2004
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2002

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2009
2010
2011
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2009

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
end