Class: Google::Apis::AppengineV1beta::Network

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Extra network settings. Only applicable in the App Engine flexible environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Network

Returns a new instance of Network.



2089
2090
2091
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forwarded_portsArray<String>

List of ports, or port pairs, to forward from the virtual machine to the application container. Only applicable in the App Engine flexible environment. Corresponds to the JSON property forwardedPorts

Returns:

  • (Array<String>)


2045
2046
2047
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2045

def forwarded_ports
  @forwarded_ports
end

#instance_ip_modeString

The IP mode for instances. Only applicable in the App Engine flexible environment. Corresponds to the JSON property instanceIpMode

Returns:

  • (String)


2051
2052
2053
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2051

def instance_ip_mode
  @instance_ip_mode
end

#instance_tagString

Tag to apply to the instance during creation. Only applicable in the App Engine flexible environment. Corresponds to the JSON property instanceTag

Returns:

  • (String)


2057
2058
2059
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2057

def instance_tag
  @instance_tag
end

#nameString

Google Compute Engine network where the virtual machines are created. Specify the short name, not the resource path.Defaults to default. Corresponds to the JSON property name

Returns:

  • (String)


2063
2064
2065
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2063

def name
  @name
end

#session_affinityBoolean Also known as: session_affinity?

Enable session affinity. Only applicable in the App Engine flexible environment. Corresponds to the JSON property sessionAffinity

Returns:

  • (Boolean)


2069
2070
2071
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2069

def session_affinity
  @session_affinity
end

#subnetwork_nameString

Google Cloud Platform sub-network where the virtual machines are created. Specify the short name, not the resource path.If a subnetwork name is specified, a network name will also be required unless it is for the default network. If the network that the instance is being created in is a Legacy network, then the IP address is allocated from the IPv4Range. If the network that the instance is being created in is an auto Subnet Mode Network, then only network name should be specified (not the subnetwork_name) and the IP address is created from the IPCidrRange of the subnetwork that exists in that zone for that network. If the network that the instance is being created in is a custom Subnet Mode Network, then the subnetwork_name must be specified and the IP address is created from the IPCidrRange of the subnetwork.If specified, the subnetwork must exist in the same region as the App Engine flexible environment application. Corresponds to the JSON property subnetworkName

Returns:

  • (String)


2087
2088
2089
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2087

def subnetwork_name
  @subnetwork_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2094
2095
2096
2097
2098
2099
2100
2101
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2094

def update!(**args)
  @forwarded_ports = args[:forwarded_ports] if args.key?(:forwarded_ports)
  @instance_ip_mode = args[:instance_ip_mode] if args.key?(:instance_ip_mode)
  @instance_tag = args[:instance_tag] if args.key?(:instance_tag)
  @name = args[:name] if args.key?(:name)
  @session_affinity = args[:session_affinity] if args.key?(:session_affinity)
  @subnetwork_name = args[:subnetwork_name] if args.key?(:subnetwork_name)
end