Class: Google::Apis::AppengineV1beta::OperationMetadataV1Alpha
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::OperationMetadataV1Alpha
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Metadata for the given google.longrunning.Operation.
Instance Attribute Summary collapse
-
#create_version_metadata ⇒ Google::Apis::AppengineV1beta::CreateVersionMetadataV1Alpha
Metadata for the given google.longrunning.Operation during a google.appengine.
-
#end_time ⇒ String
Time that this operation completed.@OutputOnly Corresponds to the JSON property
endTime. -
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled.
-
#insert_time ⇒ String
Time that this operation was created.@OutputOnly Corresponds to the JSON property
insertTime. -
#method_prop ⇒ String
API method that initiated this operation.
-
#target ⇒ String
Name of the resource that this operation is acting on.
-
#user ⇒ String
User who requested this operation.@OutputOnly Corresponds to the JSON property
user. -
#warning ⇒ Array<String>
Durable messages that persist on every operation poll.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadataV1Alpha
constructor
A new instance of OperationMetadataV1Alpha.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadataV1Alpha
Returns a new instance of OperationMetadataV1Alpha.
2314 2315 2316 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_version_metadata ⇒ Google::Apis::AppengineV1beta::CreateVersionMetadataV1Alpha
Metadata for the given google.longrunning.Operation during a google.appengine.
v1alpha.CreateVersionRequest.
Corresponds to the JSON property createVersionMetadata
2274 2275 2276 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2274 def @create_version_metadata end |
#end_time ⇒ String
Time that this operation completed.@OutputOnly
Corresponds to the JSON property endTime
2279 2280 2281 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2279 def end_time @end_time end |
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled. @
OutputOnly
Corresponds to the JSON property ephemeralMessage
2285 2286 2287 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2285 def @ephemeral_message end |
#insert_time ⇒ String
Time that this operation was created.@OutputOnly
Corresponds to the JSON property insertTime
2290 2291 2292 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2290 def insert_time @insert_time end |
#method_prop ⇒ String
API method that initiated this operation. Example: google.appengine.v1alpha.
Versions.CreateVersion.@OutputOnly
Corresponds to the JSON property method
2296 2297 2298 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2296 def method_prop @method_prop end |
#target ⇒ String
Name of the resource that this operation is acting on. Example: apps/myapp/
services/default.@OutputOnly
Corresponds to the JSON property target
2302 2303 2304 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2302 def target @target end |
#user ⇒ String
User who requested this operation.@OutputOnly
Corresponds to the JSON property user
2307 2308 2309 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2307 def user @user end |
#warning ⇒ Array<String>
Durable messages that persist on every operation poll. @OutputOnly
Corresponds to the JSON property warning
2312 2313 2314 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2312 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2319 def update!(**args) @create_version_metadata = args[:create_version_metadata] if args.key?(:create_version_metadata) @end_time = args[:end_time] if args.key?(:end_time) @ephemeral_message = args[:ephemeral_message] if args.key?(:ephemeral_message) @insert_time = args[:insert_time] if args.key?(:insert_time) @method_prop = args[:method_prop] if args.key?(:method_prop) @target = args[:target] if args.key?(:target) @user = args[:user] if args.key?(:user) @warning = args[:warning] if args.key?(:warning) end |