Class: Google::Apis::AppengineV1beta::OperationMetadataV1Beta
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::OperationMetadataV1Beta
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Metadata for the given google.longrunning.Operation.
Instance Attribute Summary collapse
-
#create_version_metadata ⇒ Google::Apis::AppengineV1beta::CreateVersionMetadataV1Beta
Metadata for the given google.longrunning.Operation during a google.appengine.
-
#end_time ⇒ String
Time that this operation completed.@OutputOnly Corresponds to the JSON property
endTime. -
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled.
-
#insert_time ⇒ String
Time that this operation was created.@OutputOnly Corresponds to the JSON property
insertTime. -
#method_prop ⇒ String
API method that initiated this operation.
-
#target ⇒ String
Name of the resource that this operation is acting on.
-
#user ⇒ String
User who requested this operation.@OutputOnly Corresponds to the JSON property
user. -
#warning ⇒ Array<String>
Durable messages that persist on every operation poll.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadataV1Beta
constructor
A new instance of OperationMetadataV1Beta.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadataV1Beta
Returns a new instance of OperationMetadataV1Beta.
2379 2380 2381 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_version_metadata ⇒ Google::Apis::AppengineV1beta::CreateVersionMetadataV1Beta
Metadata for the given google.longrunning.Operation during a google.appengine.
v1beta.CreateVersionRequest.
Corresponds to the JSON property createVersionMetadata
2339 2340 2341 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2339 def @create_version_metadata end |
#end_time ⇒ String
Time that this operation completed.@OutputOnly
Corresponds to the JSON property endTime
2344 2345 2346 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2344 def end_time @end_time end |
#ephemeral_message ⇒ String
Ephemeral message that may change every time the operation is polled. @
OutputOnly
Corresponds to the JSON property ephemeralMessage
2350 2351 2352 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2350 def @ephemeral_message end |
#insert_time ⇒ String
Time that this operation was created.@OutputOnly
Corresponds to the JSON property insertTime
2355 2356 2357 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2355 def insert_time @insert_time end |
#method_prop ⇒ String
API method that initiated this operation. Example: google.appengine.v1beta.
Versions.CreateVersion.@OutputOnly
Corresponds to the JSON property method
2361 2362 2363 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2361 def method_prop @method_prop end |
#target ⇒ String
Name of the resource that this operation is acting on. Example: apps/myapp/
services/default.@OutputOnly
Corresponds to the JSON property target
2367 2368 2369 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2367 def target @target end |
#user ⇒ String
User who requested this operation.@OutputOnly
Corresponds to the JSON property user
2372 2373 2374 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2372 def user @user end |
#warning ⇒ Array<String>
Durable messages that persist on every operation poll. @OutputOnly
Corresponds to the JSON property warning
2377 2378 2379 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2377 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2384 def update!(**args) @create_version_metadata = args[:create_version_metadata] if args.key?(:create_version_metadata) @end_time = args[:end_time] if args.key?(:end_time) @ephemeral_message = args[:ephemeral_message] if args.key?(:ephemeral_message) @insert_time = args[:insert_time] if args.key?(:insert_time) @method_prop = args[:method_prop] if args.key?(:method_prop) @target = args[:target] if args.key?(:target) @user = args[:user] if args.key?(:user) @warning = args[:warning] if args.key?(:warning) end |