Class: Google::Apis::AppengineV1beta::ProjectEvent
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::ProjectEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
The request sent to CLHs during project events.
Instance Attribute Summary collapse
-
#event_id ⇒ String
The unique ID for this project event.
-
#phase ⇒ String
Phase indicates when in the container event propagation this event is being communicated.
-
#project_metadata ⇒ Google::Apis::AppengineV1beta::ProjectsMetadata
ProjectsMetadata is the metadata CCFE stores about the all the relevant projects (tenant, consumer, producer).
-
#state ⇒ Google::Apis::AppengineV1beta::ContainerState
ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectEvent
constructor
A new instance of ProjectEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectEvent
Returns a new instance of ProjectEvent.
2450 2451 2452 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
The unique ID for this project event. CLHs can use this value to dedup
repeated calls. required
Corresponds to the JSON property eventId
2427 2428 2429 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2427 def event_id @event_id end |
#phase ⇒ String
Phase indicates when in the container event propagation this event is being
communicated. Events are sent before and after the per-resource events are
propagated. required
Corresponds to the JSON property phase
2434 2435 2436 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2434 def phase @phase end |
#project_metadata ⇒ Google::Apis::AppengineV1beta::ProjectsMetadata
ProjectsMetadata is the metadata CCFE stores about the all the relevant
projects (tenant, consumer, producer).
Corresponds to the JSON property projectMetadata
2440 2441 2442 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2440 def @project_metadata end |
#state ⇒ Google::Apis::AppengineV1beta::ContainerState
ContainerState contains the externally-visible container state that is used to
communicate the state and reasoning for that state to the CLH. This data is
not persisted by CCFE, but is instead derived from CCFE's internal
representation of the container state.
Corresponds to the JSON property state
2448 2449 2450 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2448 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2455 2456 2457 2458 2459 2460 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2455 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @phase = args[:phase] if args.key?(:phase) @project_metadata = args[:project_metadata] if args.key?(:project_metadata) @state = args[:state] if args.key?(:state) end |