Class: Google::Apis::AppengineV1beta::ReadinessCheck

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Readiness checking configuration for VM instances. Unhealthy instances are removed from traffic rotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReadinessCheck

Returns a new instance of ReadinessCheck.



2589
2590
2591
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_start_timeoutString

A maximum time limit on application initialization, measured from moment the application successfully replies to a healthcheck until it is ready to serve traffic. Corresponds to the JSON property appStartTimeout

Returns:

  • (String)


2556
2557
2558
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2556

def app_start_timeout
  @app_start_timeout
end

#check_intervalString

Interval between health checks. Corresponds to the JSON property checkInterval

Returns:

  • (String)


2561
2562
2563
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2561

def check_interval
  @check_interval
end

#failure_thresholdFixnum

Number of consecutive failed checks required before removing traffic. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


2566
2567
2568
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2566

def failure_threshold
  @failure_threshold
end

#hostString

Host header to send when performing a HTTP Readiness check. Example: "myapp. appspot.com" Corresponds to the JSON property host

Returns:

  • (String)


2572
2573
2574
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2572

def host
  @host
end

#pathString

The request path. Corresponds to the JSON property path

Returns:

  • (String)


2577
2578
2579
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2577

def path
  @path
end

#success_thresholdFixnum

Number of consecutive successful checks required before receiving traffic. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


2582
2583
2584
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2582

def success_threshold
  @success_threshold
end

#timeoutString

Time before the check is considered failed. Corresponds to the JSON property timeout

Returns:

  • (String)


2587
2588
2589
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2587

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2594

def update!(**args)
  @app_start_timeout = args[:app_start_timeout] if args.key?(:app_start_timeout)
  @check_interval = args[:check_interval] if args.key?(:check_interval)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @timeout = args[:timeout] if args.key?(:timeout)
end