Class: Google::Apis::AppengineV1beta::Runtime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Runtime versions for App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Runtime

Returns a new instance of Runtime.



2878
2879
2880
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#decommissioned_dateGoogle::Apis::AppengineV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: A full date, with non-zero year, month, and day values. A month and day, with a zero year (for example, an anniversary). A year on its own, with a zero month and a zero day. A year and month, with a zero day (for example, a credit card expiration date).Related types: google.type.TimeOfDay google.type. DateTime google.protobuf.Timestamp Corresponds to the JSON property decommissionedDate



2822
2823
2824
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2822

def decommissioned_date
  @decommissioned_date
end

#deprecation_dateGoogle::Apis::AppengineV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: A full date, with non-zero year, month, and day values. A month and day, with a zero year (for example, an anniversary). A year on its own, with a zero month and a zero day. A year and month, with a zero day (for example, a credit card expiration date).Related types: google.type.TimeOfDay google.type. DateTime google.protobuf.Timestamp Corresponds to the JSON property deprecationDate



2834
2835
2836
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2834

def deprecation_date
  @deprecation_date
end

#display_nameString

User-friendly display name, e.g. 'Node.js 12', etc. Corresponds to the JSON property displayName

Returns:

  • (String)


2839
2840
2841
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2839

def display_name
  @display_name
end

#end_of_support_dateGoogle::Apis::AppengineV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: A full date, with non-zero year, month, and day values. A month and day, with a zero year (for example, an anniversary). A year on its own, with a zero month and a zero day. A year and month, with a zero day (for example, a credit card expiration date).Related types: google.type.TimeOfDay google.type. DateTime google.protobuf.Timestamp Corresponds to the JSON property endOfSupportDate



2851
2852
2853
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2851

def end_of_support_date
  @end_of_support_date
end

#environmentString

The environment of the runtime. Corresponds to the JSON property environment

Returns:

  • (String)


2856
2857
2858
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2856

def environment
  @environment
end

#nameString

The name of the runtime, e.g., 'go113', 'nodejs12', etc. Corresponds to the JSON property name

Returns:

  • (String)


2861
2862
2863
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2861

def name
  @name
end

#stageString

The stage of life this runtime is in, e.g., BETA, GA, etc. Corresponds to the JSON property stage

Returns:

  • (String)


2866
2867
2868
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2866

def stage
  @stage
end

#supported_operating_systemsArray<String>

Supported operating systems for the runtime, e.g., 'ubuntu22', etc. Corresponds to the JSON property supportedOperatingSystems

Returns:

  • (Array<String>)


2871
2872
2873
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2871

def supported_operating_systems
  @supported_operating_systems
end

#warningsArray<String>

Warning messages, e.g., a deprecation warning. Corresponds to the JSON property warnings

Returns:

  • (Array<String>)


2876
2877
2878
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2876

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2883

def update!(**args)
  @decommissioned_date = args[:decommissioned_date] if args.key?(:decommissioned_date)
  @deprecation_date = args[:deprecation_date] if args.key?(:deprecation_date)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_of_support_date = args[:end_of_support_date] if args.key?(:end_of_support_date)
  @environment = args[:environment] if args.key?(:environment)
  @name = args[:name] if args.key?(:name)
  @stage = args[:stage] if args.key?(:stage)
  @supported_operating_systems = args[:supported_operating_systems] if args.key?(:supported_operating_systems)
  @warnings = args[:warnings] if args.key?(:warnings)
end