Class: Google::Apis::AppengineV1beta::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

A Service resource is a logical component of an application that can share state and communicate in a secure fashion with other services. For example, an application that handles customer requests might include separate services to handle tasks such as backend data analysis or API requests from mobile devices. Each service has a collection of versions that define a specific set of code used to implement the functionality of that service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



2969
2970
2971
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generated_customer_metadataHash<String,Object>

Additional Google Generated Customer Metadata, this field won't be provided by default and can be requested by setting the IncludeExtraData field in GetServiceRequest Corresponds to the JSON property generatedCustomerMetadata

Returns:

  • (Hash<String,Object>)


2929
2930
2931
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2929

def 
  @generated_customer_metadata
end

#idString

Output only. Relative name of the service within the application. Example: default.@OutputOnly Corresponds to the JSON property id

Returns:

  • (String)


2935
2936
2937
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2935

def id
  @id
end

#labelsHash<String,String>

A set of labels to apply to this service. Labels are key/value pairs that describe the service and all resources that belong to it (e.g., versions). The labels can be used to search and group resources, and are propagated to the usage and billing reports, enabling fine-grain analysis of costs. An example of using labels is to tag resources belonging to different environments (e.g., "env=prod", "env=qa"). Label keys and values can be no longer than 63 characters and can only contain lowercase letters, numeric characters, underscores, dashes, and international characters. Label keys must start with a lowercase letter or an international character. Each service can have at most 32 labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2949
2950
2951
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2949

def labels
  @labels
end

#nameString

Output only. Full path to the Service resource in the API. Example: apps/myapp/ services/default.@OutputOnly Corresponds to the JSON property name

Returns:

  • (String)


2955
2956
2957
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2955

def name
  @name
end

#network_settingsGoogle::Apis::AppengineV1beta::NetworkSettings

A NetworkSettings resource is a container for ingress settings for a version or service. Corresponds to the JSON property networkSettings



2961
2962
2963
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2961

def network_settings
  @network_settings
end

#splitGoogle::Apis::AppengineV1beta::TrafficSplit

Traffic routing configuration for versions within a single service. Traffic splits define how traffic directed to the service is assigned to versions. Corresponds to the JSON property split



2967
2968
2969
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2967

def split
  @split
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2974
2975
2976
2977
2978
2979
2980
2981
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2974

def update!(**args)
  @generated_customer_metadata = args[:generated_customer_metadata] if args.key?(:generated_customer_metadata)
  @id = args[:id] if args.key?(:id)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network_settings = args[:network_settings] if args.key?(:network_settings)
  @split = args[:split] if args.key?(:split)
end