Class: Google::Apis::AppengineV1beta::StaticFilesHandler
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::StaticFilesHandler
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files. Static file handlers describe which files in the application directory are static files, and which URLs serve them.
Instance Attribute Summary collapse
-
#application_readable ⇒ Boolean
(also: #application_readable?)
Whether files should also be uploaded as code data.
-
#expiration ⇒ String
Time a static file served by this handler should be cached by web proxies and browsers.
-
#http_headers ⇒ Hash<String,String>
HTTP headers to use for all responses from these URLs.
-
#mime_type ⇒ String
MIME type used to serve all files served by this handler.Defaults to file- specific MIME types, which are derived from each file's filename extension.
-
#path ⇒ String
Path to the static files matched by the URL pattern, from the application root directory.
-
#require_matching_file ⇒ Boolean
(also: #require_matching_file?)
Whether this handler should match the request if the file referenced by the handler does not exist.
-
#upload_path_regex ⇒ String
Regular expression that matches the file paths for all files that should be referenced by this handler.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StaticFilesHandler
constructor
A new instance of StaticFilesHandler.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StaticFilesHandler
Returns a new instance of StaticFilesHandler.
3118 3119 3120 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#application_readable ⇒ Boolean Also known as: application_readable?
Whether files should also be uploaded as code data. By default, files declared
in static file handlers are uploaded as static data and are only served to end
users; they cannot be read by the application. If enabled, uploads are charged
against both your code and static data storage resource quotas.
Corresponds to the JSON property applicationReadable
3079 3080 3081 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3079 def application_readable @application_readable end |
#expiration ⇒ String
Time a static file served by this handler should be cached by web proxies and
browsers.
Corresponds to the JSON property expiration
3086 3087 3088 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3086 def expiration @expiration end |
#http_headers ⇒ Hash<String,String>
HTTP headers to use for all responses from these URLs.
Corresponds to the JSON property httpHeaders
3091 3092 3093 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3091 def http_headers @http_headers end |
#mime_type ⇒ String
MIME type used to serve all files served by this handler.Defaults to file-
specific MIME types, which are derived from each file's filename extension.
Corresponds to the JSON property mimeType
3097 3098 3099 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3097 def mime_type @mime_type end |
#path ⇒ String
Path to the static files matched by the URL pattern, from the application root
directory. The path can refer to text matched in groupings in the URL pattern.
Corresponds to the JSON property path
3103 3104 3105 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3103 def path @path end |
#require_matching_file ⇒ Boolean Also known as: require_matching_file?
Whether this handler should match the request if the file referenced by the
handler does not exist.
Corresponds to the JSON property requireMatchingFile
3109 3110 3111 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3109 def require_matching_file @require_matching_file end |
#upload_path_regex ⇒ String
Regular expression that matches the file paths for all files that should be
referenced by this handler.
Corresponds to the JSON property uploadPathRegex
3116 3117 3118 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3116 def upload_path_regex @upload_path_regex end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3123 3124 3125 3126 3127 3128 3129 3130 3131 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3123 def update!(**args) @application_readable = args[:application_readable] if args.key?(:application_readable) @expiration = args[:expiration] if args.key?(:expiration) @http_headers = args[:http_headers] if args.key?(:http_headers) @mime_type = args[:mime_type] if args.key?(:mime_type) @path = args[:path] if args.key?(:path) @require_matching_file = args[:require_matching_file] if args.key?(:require_matching_file) @upload_path_regex = args[:upload_path_regex] if args.key?(:upload_path_regex) end |