Class: Google::Apis::AppengineV1beta::TrafficSplit
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::TrafficSplit
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Traffic routing configuration for versions within a single service. Traffic splits define how traffic directed to the service is assigned to versions.
Instance Attribute Summary collapse
-
#allocations ⇒ Hash<String,Float>
Mapping from version IDs within the service to fractional (0.000, 1] allocations of traffic for that version.
-
#shard_by ⇒ String
Mechanism used to determine which version a request is sent to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TrafficSplit
constructor
A new instance of TrafficSplit.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TrafficSplit
Returns a new instance of TrafficSplit.
3196 3197 3198 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocations ⇒ Hash<String,Float>
Mapping from version IDs within the service to fractional (0.000, 1]
allocations of traffic for that version. Each version can be specified only
once, but some versions in the service may not have any traffic allocation.
Services that have traffic allocated cannot be deleted until either the
service is deleted or their traffic allocation is removed. Allocations must
sum to 1. Up to two decimal place precision is supported for IP-based splits
and up to three decimal places is supported for cookie-based splits.
Corresponds to the JSON property allocations
3187 3188 3189 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3187 def allocations @allocations end |
#shard_by ⇒ String
Mechanism used to determine which version a request is sent to. The traffic
selection algorithm will be stable for either type until allocations are
changed.
Corresponds to the JSON property shardBy
3194 3195 3196 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3194 def shard_by @shard_by end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3201 3202 3203 3204 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3201 def update!(**args) @allocations = args[:allocations] if args.key?(:allocations) @shard_by = args[:shard_by] if args.key?(:shard_by) end |