Class: Google::Apis::AppengineV1beta::UrlDispatchRule
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::UrlDispatchRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Rules to match an HTTP request and dispatch that request to a service.
Instance Attribute Summary collapse
-
#domain ⇒ String
Domain name to match against.
-
#path ⇒ String
Pathname within the host.
-
#service ⇒ String
Resource ID of a service in this application that should serve the matched request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlDispatchRule
constructor
A new instance of UrlDispatchRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlDispatchRule
Returns a new instance of UrlDispatchRule.
3230 3231 3232 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#domain ⇒ String
Domain name to match against. The wildcard "" is supported if specified
before a period: ".".Defaults to matching all domains: "*".
Corresponds to the JSON property domain
3215 3216 3217 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3215 def domain @domain end |
#path ⇒ String
Pathname within the host. Must start with a "/". A single "*" can be included
at the end of the path.The sum of the lengths of the domain and path may not
exceed 100 characters.
Corresponds to the JSON property path
3222 3223 3224 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3222 def path @path end |
#service ⇒ String
Resource ID of a service in this application that should serve the matched
request. The service must already exist. Example: default.
Corresponds to the JSON property service
3228 3229 3230 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3228 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3235 3236 3237 3238 3239 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3235 def update!(**args) @domain = args[:domain] if args.key?(:domain) @path = args[:path] if args.key?(:path) @service = args[:service] if args.key?(:service) end |