Class: Google::Apis::AppengineV1beta::UrlMap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

URL pattern and description of how the URL should be handled. App Engine can handle URLs by executing application code or by serving static files uploaded with the version, such as images, CSS, or JavaScript.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMap

Returns a new instance of UrlMap.



3296
3297
3298
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3296

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_endpointGoogle::Apis::AppengineV1beta::ApiEndpointHandler

Uses Google Cloud Endpoints to handle requests. Corresponds to the JSON property apiEndpoint



3251
3252
3253
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3251

def api_endpoint
  @api_endpoint
end

#auth_fail_actionString

Action to take when users access resources that require authentication. Defaults to redirect. Corresponds to the JSON property authFailAction

Returns:

  • (String)


3257
3258
3259
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3257

def auth_fail_action
  @auth_fail_action
end

#loginString

Level of login required to access this resource. Not supported for Node.js in the App Engine standard environment. Corresponds to the JSON property login

Returns:

  • (String)


3263
3264
3265
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3263

def 
  @login
end

#redirect_http_response_codeString

30x code to use when performing redirects for the secure field. Defaults to 302. Corresponds to the JSON property redirectHttpResponseCode

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3269

def redirect_http_response_code
  @redirect_http_response_code
end

#scriptGoogle::Apis::AppengineV1beta::ScriptHandler

Executes a script to handle the request that matches the URL pattern. Corresponds to the JSON property script



3274
3275
3276
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3274

def script
  @script
end

#security_levelString

Security (HTTPS) enforcement for this URL. Corresponds to the JSON property securityLevel

Returns:

  • (String)


3279
3280
3281
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3279

def security_level
  @security_level
end

#static_filesGoogle::Apis::AppengineV1beta::StaticFilesHandler

Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files. Static file handlers describe which files in the application directory are static files, and which URLs serve them. Corresponds to the JSON property staticFiles



3286
3287
3288
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3286

def static_files
  @static_files
end

#url_regexString

URL prefix. Uses regular expression syntax, which means regexp special characters must be escaped, but should not contain groupings. All URLs that begin with this prefix are handled by this handler, using the portion of the URL after the prefix as part of the file path. Corresponds to the JSON property urlRegex

Returns:

  • (String)


3294
3295
3296
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3294

def url_regex
  @url_regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3301
3302
3303
3304
3305
3306
3307
3308
3309
3310
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3301

def update!(**args)
  @api_endpoint = args[:api_endpoint] if args.key?(:api_endpoint)
  @auth_fail_action = args[:auth_fail_action] if args.key?(:auth_fail_action)
  @login = args[:login] if args.key?(:login)
  @redirect_http_response_code = args[:redirect_http_response_code] if args.key?(:redirect_http_response_code)
  @script = args[:script] if args.key?(:script)
  @security_level = args[:security_level] if args.key?(:security_level)
  @static_files = args[:static_files] if args.key?(:static_files)
  @url_regex = args[:url_regex] if args.key?(:url_regex)
end