Class: Google::Apis::AppengineV1beta::VpcAccessConnector
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::VpcAccessConnector
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
VPC access connector specification.
Instance Attribute Summary collapse
-
#egress_setting ⇒ String
The egress setting for the connector, controlling what traffic is diverted through it.
-
#name ⇒ String
Full Serverless VPC Access Connector name e.g.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpcAccessConnector
constructor
A new instance of VpcAccessConnector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpcAccessConnector
Returns a new instance of VpcAccessConnector.
3716 3717 3718 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#egress_setting ⇒ String
The egress setting for the connector, controlling what traffic is diverted
through it.
Corresponds to the JSON property egressSetting
3708 3709 3710 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3708 def egress_setting @egress_setting end |
#name ⇒ String
Full Serverless VPC Access Connector name e.g. projects/my-project/locations/
us-central1/connectors/c1.
Corresponds to the JSON property name
3714 3715 3716 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3714 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3721 3722 3723 3724 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3721 def update!(**args) @egress_setting = args[:egress_setting] if args.key?(:egress_setting) @name = args[:name] if args.key?(:name) end |