Class: Google::Apis::AppengineV1beta::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::Deployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Code and application artifacts used to deploy a version to App Engine.
Instance Attribute Summary collapse
-
#build ⇒ Google::Apis::AppengineV1beta::BuildInfo
Google Cloud Build information.
-
#cloud_build_options ⇒ Google::Apis::AppengineV1beta::CloudBuildOptions
Options for the build operations performed as a part of the version deployment.
-
#container ⇒ Google::Apis::AppengineV1beta::ContainerInfo
Docker image that is used to create a container and start a VM instance for the version that you deploy.
-
#files ⇒ Hash<String,Google::Apis::AppengineV1beta::FileInfo>
Manifest of the files stored in Google Cloud Storage that are included as part of this version.
-
#zip ⇒ Google::Apis::AppengineV1beta::ZipInfo
The zip file information for a zip deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
897 898 899 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#build ⇒ Google::Apis::AppengineV1beta::BuildInfo
Google Cloud Build information.
Corresponds to the JSON property build
869 870 871 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 869 def build @build end |
#cloud_build_options ⇒ Google::Apis::AppengineV1beta::CloudBuildOptions
Options for the build operations performed as a part of the version deployment.
Only applicable for App Engine flexible environment when creating a version
using source code directly.
Corresponds to the JSON property cloudBuildOptions
876 877 878 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 876 def @cloud_build_options end |
#container ⇒ Google::Apis::AppengineV1beta::ContainerInfo
Docker image that is used to create a container and start a VM instance for
the version that you deploy. Only applicable for instances running in the App
Engine flexible environment.
Corresponds to the JSON property container
883 884 885 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 883 def container @container end |
#files ⇒ Hash<String,Google::Apis::AppengineV1beta::FileInfo>
Manifest of the files stored in Google Cloud Storage that are included as part
of this version. All files must be readable using the credentials supplied
with this call.
Corresponds to the JSON property files
890 891 892 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 890 def files @files end |
#zip ⇒ Google::Apis::AppengineV1beta::ZipInfo
The zip file information for a zip deployment.
Corresponds to the JSON property zip
895 896 897 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 895 def zip @zip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
902 903 904 905 906 907 908 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 902 def update!(**args) @build = args[:build] if args.key?(:build) @cloud_build_options = args[:cloud_build_options] if args.key?(:cloud_build_options) @container = args[:container] if args.key?(:container) @files = args[:files] if args.key?(:files) @zip = args[:zip] if args.key?(:zip) end |