Class: Google::Apis::AppengineV1beta::FirewallRule
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::FirewallRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
A single firewall rule that is evaluated against incoming traffic and provides an action to take on matched requests. A positive integer between 1, Int32. MaxValue-1 that defines the order of rule evaluation. Rules with the lowest priority are evaluated first.A default rule at priority Int32.MaxValue matches all IPv4 and IPv6 traffic when no previous rule matches. Only the action of this rule can be modified by the user.
Instance Attribute Summary collapse
-
#action ⇒ String
The action to take on matched requests.
-
#description ⇒ String
An optional string description of this rule.
-
#priority ⇒ Fixnum
Corresponds to the JSON property
priority. -
#source_range ⇒ String
IP address or range, defined using CIDR notation, of requests that this rule applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallRule
constructor
A new instance of FirewallRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallRule
Returns a new instance of FirewallRule.
1210 1211 1212 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
The action to take on matched requests.
Corresponds to the JSON property action
1186 1187 1188 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1186 def action @action end |
#description ⇒ String
An optional string description of this rule. This field has a maximum length
of 400 characters.
Corresponds to the JSON property description
1192 1193 1194 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1192 def description @description end |
#priority ⇒ Fixnum
Corresponds to the JSON property priority
1197 1198 1199 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1197 def priority @priority end |
#source_range ⇒ String
IP address or range, defined using CIDR notation, of requests that this rule
applies to. You can use the wildcard character "*" to match all IPs equivalent
to "0/0" and "::/0" together. Examples: 192.168.1.1 or 192.168.0.0/16 or 2001:
db8::/32 or 2001:0db8:0000:0042:0000:8a2e:0370:7334. Truncation will be
silently performed on addresses which are not properly truncated. For example,
1.2.3.4/24 is accepted as the same address as 1.2.3.0/24. Similarly, for IPv6,
2001:db8::1/32 is accepted as the same address as 2001:db8::/32.
Corresponds to the JSON property sourceRange
1208 1209 1210 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1208 def source_range @source_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1215 1216 1217 1218 1219 1220 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1215 def update!(**args) @action = args[:action] if args.key?(:action) @description = args[:description] if args.key?(:description) @priority = args[:priority] if args.key?(:priority) @source_range = args[:source_range] if args.key?(:source_range) end |