Class: Google::Apis::AppengineV1beta::HealthCheck

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances. Only applicable for instances in App Engine flexible environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheck

Returns a new instance of HealthCheck.



1356
1357
1358
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_intervalString

Interval between health checks. Corresponds to the JSON property checkInterval

Returns:

  • (String)


1320
1321
1322
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1320

def check_interval
  @check_interval
end

#disable_health_checkBoolean Also known as: disable_health_check?

Whether to explicitly disable health checks for this instance. Corresponds to the JSON property disableHealthCheck

Returns:

  • (Boolean)


1325
1326
1327
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1325

def disable_health_check
  @disable_health_check
end

#healthy_thresholdFixnum

Number of consecutive successful health checks required before receiving traffic. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


1332
1333
1334
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1332

def healthy_threshold
  @healthy_threshold
end

#hostString

Host header to send when performing an HTTP health check. Example: "myapp. appspot.com" Corresponds to the JSON property host

Returns:

  • (String)


1338
1339
1340
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1338

def host
  @host
end

#restart_thresholdFixnum

Number of consecutive failed health checks required before an instance is restarted. Corresponds to the JSON property restartThreshold

Returns:

  • (Fixnum)


1344
1345
1346
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1344

def restart_threshold
  @restart_threshold
end

#timeoutString

Time before the health check is considered failed. Corresponds to the JSON property timeout

Returns:

  • (String)


1349
1350
1351
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1349

def timeout
  @timeout
end

#unhealthy_thresholdFixnum

Number of consecutive failed health checks required before removing traffic. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


1354
1355
1356
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1354

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1361
1362
1363
1364
1365
1366
1367
1368
1369
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1361

def update!(**args)
  @check_interval = args[:check_interval] if args.key?(:check_interval)
  @disable_health_check = args[:disable_health_check] if args.key?(:disable_health_check)
  @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold)
  @host = args[:host] if args.key?(:host)
  @restart_threshold = args[:restart_threshold] if args.key?(:restart_threshold)
  @timeout = args[:timeout] if args.key?(:timeout)
  @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold)
end