Class: Google::Apis::AppengineV1beta::LivenessCheck
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::LivenessCheck
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances.
Instance Attribute Summary collapse
-
#check_interval ⇒ String
Interval between health checks.
-
#failure_threshold ⇒ Fixnum
Number of consecutive failed checks required before considering the VM unhealthy.
-
#host ⇒ String
Host header to send when performing a HTTP Liveness check.
-
#initial_delay ⇒ String
The initial delay before starting to execute the checks.
-
#path ⇒ String
The request path.
-
#success_threshold ⇒ Fixnum
Number of consecutive successful checks required before considering the VM healthy.
-
#timeout ⇒ String
Time before the check is considered failed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LivenessCheck
constructor
A new instance of LivenessCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LivenessCheck
Returns a new instance of LivenessCheck.
1889 1890 1891 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_interval ⇒ String
Interval between health checks.
Corresponds to the JSON property checkInterval
1854 1855 1856 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1854 def check_interval @check_interval end |
#failure_threshold ⇒ Fixnum
Number of consecutive failed checks required before considering the VM
unhealthy.
Corresponds to the JSON property failureThreshold
1860 1861 1862 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1860 def failure_threshold @failure_threshold end |
#host ⇒ String
Host header to send when performing a HTTP Liveness check. Example: "myapp.
appspot.com"
Corresponds to the JSON property host
1866 1867 1868 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1866 def host @host end |
#initial_delay ⇒ String
The initial delay before starting to execute the checks.
Corresponds to the JSON property initialDelay
1871 1872 1873 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1871 def initial_delay @initial_delay end |
#path ⇒ String
The request path.
Corresponds to the JSON property path
1876 1877 1878 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1876 def path @path end |
#success_threshold ⇒ Fixnum
Number of consecutive successful checks required before considering the VM
healthy.
Corresponds to the JSON property successThreshold
1882 1883 1884 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1882 def success_threshold @success_threshold end |
#timeout ⇒ String
Time before the check is considered failed.
Corresponds to the JSON property timeout
1887 1888 1889 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1887 def timeout @timeout end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1894 1895 1896 1897 1898 1899 1900 1901 1902 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1894 def update!(**args) @check_interval = args[:check_interval] if args.key?(:check_interval) @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold) @host = args[:host] if args.key?(:host) @initial_delay = args[:initial_delay] if args.key?(:initial_delay) @path = args[:path] if args.key?(:path) @success_threshold = args[:success_threshold] if args.key?(:success_threshold) @timeout = args[:timeout] if args.key?(:timeout) end |