Class: Google::Apis::AppengineV1beta::LivenessCheck

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LivenessCheck

Returns a new instance of LivenessCheck.



1866
1867
1868
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_intervalString

Interval between health checks. Corresponds to the JSON property checkInterval

Returns:

  • (String)


1831
1832
1833
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1831

def check_interval
  @check_interval
end

#failure_thresholdFixnum

Number of consecutive failed checks required before considering the VM unhealthy. Corresponds to the JSON property failureThreshold

Returns:

  • (Fixnum)


1837
1838
1839
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1837

def failure_threshold
  @failure_threshold
end

#hostString

Host header to send when performing a HTTP Liveness check. Example: "myapp. appspot.com" Corresponds to the JSON property host

Returns:

  • (String)


1843
1844
1845
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1843

def host
  @host
end

#initial_delayString

The initial delay before starting to execute the checks. Corresponds to the JSON property initialDelay

Returns:

  • (String)


1848
1849
1850
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1848

def initial_delay
  @initial_delay
end

#pathString

The request path. Corresponds to the JSON property path

Returns:

  • (String)


1853
1854
1855
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1853

def path
  @path
end

#success_thresholdFixnum

Number of consecutive successful checks required before considering the VM healthy. Corresponds to the JSON property successThreshold

Returns:

  • (Fixnum)


1859
1860
1861
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1859

def success_threshold
  @success_threshold
end

#timeoutString

Time before the check is considered failed. Corresponds to the JSON property timeout

Returns:

  • (String)


1864
1865
1866
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1864

def timeout
  @timeout
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1871

def update!(**args)
  @check_interval = args[:check_interval] if args.key?(:check_interval)
  @failure_threshold = args[:failure_threshold] if args.key?(:failure_threshold)
  @host = args[:host] if args.key?(:host)
  @initial_delay = args[:initial_delay] if args.key?(:initial_delay)
  @path = args[:path] if args.key?(:path)
  @success_threshold = args[:success_threshold] if args.key?(:success_threshold)
  @timeout = args[:timeout] if args.key?(:timeout)
end