Class: Google::Apis::AppengineV1beta::ManagedCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

A certificate managed by App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedCertificate

Returns a new instance of ManagedCertificate.



1981
1982
1983
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_renewal_timeString

Time at which the certificate was last renewed. The renewal process is fully managed. Certificate renewal will automatically occur before the certificate expires. Renewal errors can be tracked via ManagementStatus.@OutputOnly Corresponds to the JSON property lastRenewalTime

Returns:

  • (String)


1973
1974
1975
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1973

def last_renewal_time
  @last_renewal_time
end

#statusString

Status of certificate management. Refers to the most recent certificate acquisition or renewal attempt.@OutputOnly Corresponds to the JSON property status

Returns:

  • (String)


1979
1980
1981
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1979

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1986
1987
1988
1989
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 1986

def update!(**args)
  @last_renewal_time = args[:last_renewal_time] if args.key?(:last_renewal_time)
  @status = args[:status] if args.key?(:status)
end