Class: Google::Apis::AppengineV1beta::ProjectEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

The request sent to CLHs during project events.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectEvent

Returns a new instance of ProjectEvent.



2427
2428
2429
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

The unique ID for this project event. CLHs can use this value to dedup repeated calls. required Corresponds to the JSON property eventId

Returns:

  • (String)


2404
2405
2406
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2404

def event_id
  @event_id
end

#phaseString

Phase indicates when in the container event propagation this event is being communicated. Events are sent before and after the per-resource events are propagated. required Corresponds to the JSON property phase

Returns:

  • (String)


2411
2412
2413
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2411

def phase
  @phase
end

#project_metadataGoogle::Apis::AppengineV1beta::ProjectsMetadata

ProjectsMetadata is the metadata CCFE stores about the all the relevant projects (tenant, consumer, producer). Corresponds to the JSON property projectMetadata



2417
2418
2419
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2417

def 
  @project_metadata
end

#stateGoogle::Apis::AppengineV1beta::ContainerState

ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH. This data is not persisted by CCFE, but is instead derived from CCFE's internal representation of the container state. Corresponds to the JSON property state



2425
2426
2427
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2425

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2432
2433
2434
2435
2436
2437
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2432

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @phase = args[:phase] if args.key?(:phase)
  @project_metadata = args[:project_metadata] if args.key?(:project_metadata)
  @state = args[:state] if args.key?(:state)
end