Class: Google::Apis::AppengineV1beta::ProjectsMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

ProjectsMetadata is the metadata CCFE stores about the all the relevant projects (tenant, consumer, producer).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsMetadata

Returns a new instance of ProjectsMetadata.



2504
2505
2506
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_project_idString

The consumer project id. Corresponds to the JSON property consumerProjectId

Returns:

  • (String)


2448
2449
2450
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2448

def consumer_project_id
  @consumer_project_id
end

#consumer_project_numberFixnum

The consumer project number. Corresponds to the JSON property consumerProjectNumber

Returns:

  • (Fixnum)


2453
2454
2455
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2453

def consumer_project_number
  @consumer_project_number
end

#consumer_project_stateString

The CCFE state of the consumer project. It is the same state that is communicated to the CLH during project events. Notice that this field is not set in the DB, it is only set in this proto when communicated to CLH in the side channel. Corresponds to the JSON property consumerProjectState

Returns:

  • (String)


2461
2462
2463
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2461

def consumer_project_state
  @consumer_project_state
end

#gce_tagArray<Google::Apis::AppengineV1beta::GceTag>

The GCE tags associated with the consumer project and those inherited due to their ancestry, if any. Not supported by CCFE. Corresponds to the JSON property gceTag



2467
2468
2469
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2467

def gce_tag
  @gce_tag
end

#is_gce_project_deprovisioningBoolean Also known as: is_gce_project_deprovisioning?

DEPRECATED: Indicates whether the GCE project is in the DEPROVISIONING state. This field is a temporary workaround (see b/475310865) to allow GCE extensions to bypass certain checks during deprovisioning. It will be replaced by a permanent solution in the future. Corresponds to the JSON property isGceProjectDeprovisioning

Returns:

  • (Boolean)


2475
2476
2477
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2475

def is_gce_project_deprovisioning
  @is_gce_project_deprovisioning
end

#p4_service_accountString

The service account authorized to operate on the consumer project. Note: CCFE only propagates P4SA with default tag to CLH. Corresponds to the JSON property p4ServiceAccount

Returns:

  • (String)


2482
2483
2484
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2482

def 
  @p4_service_account
end

#producer_project_idString

The producer project id. Corresponds to the JSON property producerProjectId

Returns:

  • (String)


2487
2488
2489
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2487

def producer_project_id
  @producer_project_id
end

#producer_project_numberFixnum

The producer project number. Corresponds to the JSON property producerProjectNumber

Returns:

  • (Fixnum)


2492
2493
2494
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2492

def producer_project_number
  @producer_project_number
end

#tenant_project_idString

The tenant project id. Corresponds to the JSON property tenantProjectId

Returns:

  • (String)


2497
2498
2499
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2497

def tenant_project_id
  @tenant_project_id
end

#tenant_project_numberFixnum

The tenant project number. Corresponds to the JSON property tenantProjectNumber

Returns:

  • (Fixnum)


2502
2503
2504
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2502

def tenant_project_number
  @tenant_project_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2509

def update!(**args)
  @consumer_project_id = args[:consumer_project_id] if args.key?(:consumer_project_id)
  @consumer_project_number = args[:consumer_project_number] if args.key?(:consumer_project_number)
  @consumer_project_state = args[:consumer_project_state] if args.key?(:consumer_project_state)
  @gce_tag = args[:gce_tag] if args.key?(:gce_tag)
  @is_gce_project_deprovisioning = args[:is_gce_project_deprovisioning] if args.key?(:is_gce_project_deprovisioning)
  @p4_service_account = args[:p4_service_account] if args.key?(:p4_service_account)
  @producer_project_id = args[:producer_project_id] if args.key?(:producer_project_id)
  @producer_project_number = args[:producer_project_number] if args.key?(:producer_project_number)
  @tenant_project_id = args[:tenant_project_id] if args.key?(:tenant_project_id)
  @tenant_project_number = args[:tenant_project_number] if args.key?(:tenant_project_number)
end