Class: Google::Apis::AppengineV1beta::Reasons
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::Reasons
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller)
Instance Attribute Summary collapse
-
#abuse ⇒ String
Corresponds to the JSON property
abuse. -
#billing ⇒ String
Corresponds to the JSON property
billing. -
#data_governance ⇒ String
Corresponds to the JSON property
dataGovernance. -
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
-
#service_management ⇒ String
Corresponds to the JSON property
serviceManagement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reasons
constructor
A new instance of Reasons.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reasons
Returns a new instance of Reasons.
2640 2641 2642 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abuse ⇒ String
Corresponds to the JSON property abuse
2616 2617 2618 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2616 def abuse @abuse end |
#billing ⇒ String
Corresponds to the JSON property billing
2621 2622 2623 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2621 def billing @billing end |
#data_governance ⇒ String
Corresponds to the JSON property dataGovernance
2626 2627 2628 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2626 def data_governance @data_governance end |
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
This information could be used to clean up resources in case service in
DISABLED_FULL i.e. Service is inactive > 30 days.
Corresponds to the JSON property serviceActivation
2633 2634 2635 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2633 def service_activation @service_activation end |
#service_management ⇒ String
Corresponds to the JSON property serviceManagement
2638 2639 2640 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2638 def service_management @service_management end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2645 2646 2647 2648 2649 2650 2651 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2645 def update!(**args) @abuse = args[:abuse] if args.key?(:abuse) @billing = args[:billing] if args.key?(:billing) @data_governance = args[:data_governance] if args.key?(:data_governance) @service_activation = args[:service_activation] if args.key?(:service_activation) @service_management = args[:service_management] if args.key?(:service_management) end |