Class: Google::Apis::AppengineV1beta::Reasons

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reasons

Returns a new instance of Reasons.



2617
2618
2619
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abuseString

Corresponds to the JSON property abuse

Returns:

  • (String)


2593
2594
2595
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2593

def abuse
  @abuse
end

#billingString

Corresponds to the JSON property billing

Returns:

  • (String)


2598
2599
2600
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2598

def billing
  @billing
end

#data_governanceString

Corresponds to the JSON property dataGovernance

Returns:

  • (String)


2603
2604
2605
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2603

def data_governance
  @data_governance
end

#service_activationString

Consumer Container denotes if the service is active within a project or not. This information could be used to clean up resources in case service in DISABLED_FULL i.e. Service is inactive > 30 days. Corresponds to the JSON property serviceActivation

Returns:

  • (String)


2610
2611
2612
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2610

def service_activation
  @service_activation
end

#service_managementString

Corresponds to the JSON property serviceManagement

Returns:

  • (String)


2615
2616
2617
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2615

def service_management
  @service_management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2622
2623
2624
2625
2626
2627
2628
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2622

def update!(**args)
  @abuse = args[:abuse] if args.key?(:abuse)
  @billing = args[:billing] if args.key?(:billing)
  @data_governance = args[:data_governance] if args.key?(:data_governance)
  @service_activation = args[:service_activation] if args.key?(:service_activation)
  @service_management = args[:service_management] if args.key?(:service_management)
end