Class: Google::Apis::AppengineV1beta::Runtime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

Runtime versions for App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Runtime

Returns a new instance of Runtime.



2855
2856
2857
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#decommissioned_dateGoogle::Apis::AppengineV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: A full date, with non-zero year, month, and day values. A month and day, with a zero year (for example, an anniversary). A year on its own, with a zero month and a zero day. A year and month, with a zero day (for example, a credit card expiration date).Related types: google.type.TimeOfDay google.type. DateTime google.protobuf.Timestamp Corresponds to the JSON property decommissionedDate



2799
2800
2801
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2799

def decommissioned_date
  @decommissioned_date
end

#deprecation_dateGoogle::Apis::AppengineV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: A full date, with non-zero year, month, and day values. A month and day, with a zero year (for example, an anniversary). A year on its own, with a zero month and a zero day. A year and month, with a zero day (for example, a credit card expiration date).Related types: google.type.TimeOfDay google.type. DateTime google.protobuf.Timestamp Corresponds to the JSON property deprecationDate



2811
2812
2813
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2811

def deprecation_date
  @deprecation_date
end

#display_nameString

User-friendly display name, e.g. 'Node.js 12', etc. Corresponds to the JSON property displayName

Returns:

  • (String)


2816
2817
2818
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2816

def display_name
  @display_name
end

#end_of_support_dateGoogle::Apis::AppengineV1beta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: A full date, with non-zero year, month, and day values. A month and day, with a zero year (for example, an anniversary). A year on its own, with a zero month and a zero day. A year and month, with a zero day (for example, a credit card expiration date).Related types: google.type.TimeOfDay google.type. DateTime google.protobuf.Timestamp Corresponds to the JSON property endOfSupportDate



2828
2829
2830
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2828

def end_of_support_date
  @end_of_support_date
end

#environmentString

The environment of the runtime. Corresponds to the JSON property environment

Returns:

  • (String)


2833
2834
2835
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2833

def environment
  @environment
end

#nameString

The name of the runtime, e.g., 'go113', 'nodejs12', etc. Corresponds to the JSON property name

Returns:

  • (String)


2838
2839
2840
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2838

def name
  @name
end

#stageString

The stage of life this runtime is in, e.g., BETA, GA, etc. Corresponds to the JSON property stage

Returns:

  • (String)


2843
2844
2845
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2843

def stage
  @stage
end

#supported_operating_systemsArray<String>

Supported operating systems for the runtime, e.g., 'ubuntu22', etc. Corresponds to the JSON property supportedOperatingSystems

Returns:

  • (Array<String>)


2848
2849
2850
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2848

def supported_operating_systems
  @supported_operating_systems
end

#warningsArray<String>

Warning messages, e.g., a deprecation warning. Corresponds to the JSON property warnings

Returns:

  • (Array<String>)


2853
2854
2855
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2853

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2860

def update!(**args)
  @decommissioned_date = args[:decommissioned_date] if args.key?(:decommissioned_date)
  @deprecation_date = args[:deprecation_date] if args.key?(:deprecation_date)
  @display_name = args[:display_name] if args.key?(:display_name)
  @end_of_support_date = args[:end_of_support_date] if args.key?(:end_of_support_date)
  @environment = args[:environment] if args.key?(:environment)
  @name = args[:name] if args.key?(:name)
  @stage = args[:stage] if args.key?(:stage)
  @supported_operating_systems = args[:supported_operating_systems] if args.key?(:supported_operating_systems)
  @warnings = args[:warnings] if args.key?(:warnings)
end