Class: Google::Apis::AppengineV1beta::SslSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb

Overview

SSL configuration for a DomainMapping resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslSettings

Returns a new instance of SslSettings.



2993
2994
2995
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_idString

ID of the AuthorizedCertificate resource configuring SSL for the application. Clearing this field will remove SSL support.By default, a managed certificate is automatically created for every domain mapping. To omit SSL support or to configure SSL manually, specify SslManagementType.MANUAL on a CREATE or UPDATE request. You must be authorized to administer the AuthorizedCertificate resource to manually map it to a DomainMapping resource. Example: 12345. Corresponds to the JSON property certificateId

Returns:

  • (String)


2973
2974
2975
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2973

def certificate_id
  @certificate_id
end

#pending_managed_certificate_idString

Output only. ID of the managed AuthorizedCertificate resource currently being provisioned, if applicable. Until the new managed certificate has been successfully provisioned, the previous SSL state will be preserved. Once the provisioning process completes, the certificate_id field will reflect the new managed certificate and this field will be left empty. To remove SSL support while there is still a pending managed certificate, clear the certificate_id field with an UpdateDomainMappingRequest.@OutputOnly Corresponds to the JSON property pendingManagedCertificateId

Returns:

  • (String)


2984
2985
2986
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2984

def pending_managed_certificate_id
  @pending_managed_certificate_id
end

#ssl_management_typeString

SSL management type for this domain. If AUTOMATIC, a managed certificate is automatically provisioned. If MANUAL, certificate_id must be manually specified in order to configure SSL for this domain. Corresponds to the JSON property sslManagementType

Returns:

  • (String)


2991
2992
2993
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2991

def ssl_management_type
  @ssl_management_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2998
2999
3000
3001
3002
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 2998

def update!(**args)
  @certificate_id = args[:certificate_id] if args.key?(:certificate_id)
  @pending_managed_certificate_id = args[:pending_managed_certificate_id] if args.key?(:pending_managed_certificate_id)
  @ssl_management_type = args[:ssl_management_type] if args.key?(:ssl_management_type)
end