Class: Google::Apis::AppengineV1beta::UrlMap
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::UrlMap
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
URL pattern and description of how the URL should be handled. App Engine can handle URLs by executing application code or by serving static files uploaded with the version, such as images, CSS, or JavaScript.
Instance Attribute Summary collapse
-
#api_endpoint ⇒ Google::Apis::AppengineV1beta::ApiEndpointHandler
Uses Google Cloud Endpoints to handle requests.
-
#auth_fail_action ⇒ String
Action to take when users access resources that require authentication.
-
#login ⇒ String
Level of login required to access this resource.
-
#redirect_http_response_code ⇒ String
30x code to use when performing redirects for the secure field.
-
#script ⇒ Google::Apis::AppengineV1beta::ScriptHandler
Executes a script to handle the request that matches the URL pattern.
-
#security_level ⇒ String
Security (HTTPS) enforcement for this URL.
-
#static_files ⇒ Google::Apis::AppengineV1beta::StaticFilesHandler
Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files.
-
#url_regex ⇒ String
URL prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMap
constructor
A new instance of UrlMap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMap
Returns a new instance of UrlMap.
3273 3274 3275 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3273 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_endpoint ⇒ Google::Apis::AppengineV1beta::ApiEndpointHandler
Uses Google Cloud Endpoints to handle requests.
Corresponds to the JSON property apiEndpoint
3228 3229 3230 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3228 def api_endpoint @api_endpoint end |
#auth_fail_action ⇒ String
Action to take when users access resources that require authentication.
Defaults to redirect.
Corresponds to the JSON property authFailAction
3234 3235 3236 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3234 def auth_fail_action @auth_fail_action end |
#login ⇒ String
Level of login required to access this resource. Not supported for Node.js in
the App Engine standard environment.
Corresponds to the JSON property login
3240 3241 3242 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3240 def login @login end |
#redirect_http_response_code ⇒ String
30x code to use when performing redirects for the secure field. Defaults to
302.
Corresponds to the JSON property redirectHttpResponseCode
3246 3247 3248 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3246 def redirect_http_response_code @redirect_http_response_code end |
#script ⇒ Google::Apis::AppengineV1beta::ScriptHandler
Executes a script to handle the request that matches the URL pattern.
Corresponds to the JSON property script
3251 3252 3253 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3251 def script @script end |
#security_level ⇒ String
Security (HTTPS) enforcement for this URL.
Corresponds to the JSON property securityLevel
3256 3257 3258 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3256 def security_level @security_level end |
#static_files ⇒ Google::Apis::AppengineV1beta::StaticFilesHandler
Files served directly to the user for a given URL, such as images, CSS
stylesheets, or JavaScript source files. Static file handlers describe which
files in the application directory are static files, and which URLs serve them.
Corresponds to the JSON property staticFiles
3263 3264 3265 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3263 def static_files @static_files end |
#url_regex ⇒ String
URL prefix. Uses regular expression syntax, which means regexp special
characters must be escaped, but should not contain groupings. All URLs that
begin with this prefix are handled by this handler, using the portion of the
URL after the prefix as part of the file path.
Corresponds to the JSON property urlRegex
3271 3272 3273 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3271 def url_regex @url_regex end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3278 def update!(**args) @api_endpoint = args[:api_endpoint] if args.key?(:api_endpoint) @auth_fail_action = args[:auth_fail_action] if args.key?(:auth_fail_action) @login = args[:login] if args.key?(:login) @redirect_http_response_code = args[:redirect_http_response_code] if args.key?(:redirect_http_response_code) @script = args[:script] if args.key?(:script) @security_level = args[:security_level] if args.key?(:security_level) @static_files = args[:static_files] if args.key?(:static_files) @url_regex = args[:url_regex] if args.key?(:url_regex) end |