Class: Google::Apis::AppengineV1beta::VpcNetworkInterface
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1beta::VpcNetworkInterface
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1beta/classes.rb,
lib/google/apis/appengine_v1beta/representations.rb,
lib/google/apis/appengine_v1beta/representations.rb
Overview
Network interface key message.
Instance Attribute Summary collapse
-
#network ⇒ String
Optional.
-
#subnet ⇒ String
Optional.
-
#tags ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpcNetworkInterface
constructor
A new instance of VpcNetworkInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpcNetworkInterface
Returns a new instance of VpcNetworkInterface.
3734 3735 3736 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#network ⇒ String
Optional. The VPC network that the App Engine resource will be able to send
traffic to. At least one of network or subnetwork must be specified. If both
network and subnetwork are specified, the given VPC subnetwork must belong to
the given VPC network. If network is not specified, it will be looked up from
the subnetwork. Could be either a short name or a full path. e.g. VPC_NETWORK
or projects/HOST_PROJECT_ID/global/networks/VPC_NETWORK
Corresponds to the JSON property network
3716 3717 3718 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3716 def network @network end |
#subnet ⇒ String
Optional. The VPC subnetwork that the App Engine resource will get IPs from.
At least one of network or subnetwork must be specified. If both network and
subnetwork are specified, the given VPC subnetwork must belong to the given
VPC network. If subnetwork is not specified, the subnetwork with the same name
with the network will be used. Could be either a short name or a full path. e.
g. SUBNET_NAME or projects/HOST_PROJECT_ID/regions/REGION/subnetworks/
SUBNET_NAME
Corresponds to the JSON property subnet
3727 3728 3729 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3727 def subnet @subnet end |
#tags ⇒ Array<String>
Optional. The network tags that will be applied to this App Engine resource.
Corresponds to the JSON property tags
3732 3733 3734 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3732 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3739 3740 3741 3742 3743 |
# File 'lib/google/apis/appengine_v1beta/classes.rb', line 3739 def update!(**args) @network = args[:network] if args.key?(:network) @subnet = args[:subnet] if args.key?(:subnet) @tags = args[:tags] if args.key?(:tags) end |